@@ -114,5 +114,6 @@ class Modrinth(Writer):
 
         from shutil import make_archive
         name = get_name_from_scheme("MR", "Modrinth", self.intermediate)
-        archive = Path(make_archive((self.modpack_path / name).as_posix(), 'zip', self.temp_dir, '.'))
-        archive.replace(archive.with_suffix(".mrpack"))
+        archive_path = self.modpack_path.joinpath("__tmp__." + name).as_posix()
+        archive = Path(make_archive(archive_path, 'zip', self.temp_dir, '.'))
+        archive.replace(archive.with_name(name).with_suffix(".mrpack"))
